===========================
FAN-C command line plotting
===========================

The ``fancplot`` tool should be accessible from the command line after you installed FAN-C
(see :ref:`fanc_installation`).
It provides basic commands for plotting Hi-C data and other genomic tracks.

.. toctree::
   :maxdepth: 2

    Overview and basic usage <fancplot-executable/fancplot_basic>
    Working with Cooler, Juicer, and text files <fanc-executable/compatibility>
    Panel types <fancplot-executable/panel_types>
